import { InjectToken, IContainer } from '@ts-ioc/core';
import { RunnableConfigure } from './AppConfigure';
/**
 * configure manager token.
 */
export declare const ConfigureMgrToken: InjectToken<IConfigureManager<RunnableConfigure>>;
/**
 * default configuration token.
 */
export declare const DefaultConfigureToken: InjectToken<RunnableConfigure>;
/**
 * configure loader.
 *
 * @export
 * @interface IConfigureLoader
 */
export interface IConfigureLoader<T extends RunnableConfigure> {
    /**
     * load config.
     *
     * @param {string} [uri]
     * @returns {Promise<T>}
     * @memberof AppConfigureLoader
     */
    load(uri?: string): Promise<T>;
}
/**
 * configure loader token.
 */
export declare const ConfigureLoaderToken: InjectToken<IConfigureLoader<RunnableConfigure>>;
/**
 * configure register.
 *
 * @export
 * @interface IConfigureRegister
 * @template T
 */
export interface IConfigureRegister<T extends RunnableConfigure> {
    /**
     * register config setting.
     *
     * @param {T} config
     * @param {IContainer} container
     * @returns {Promise<void>}
     * @memberof IConfigureRegister
     */
    register(config: T, container: IContainer): Promise<void>;
}
/**
 * configure register token.
 */
export declare const ConfigureRegisterToken: InjectToken<IConfigureRegister<RunnableConfigure>>;
/**
 * configure manager.
 *
 * @export
 * @interface IConfigureManager
 * @template T
 */
export interface IConfigureManager<T extends RunnableConfigure> {
    /**
     * use configuration.
     *
     * @param {(string | AppConfigure)} [config]
     * @returns {this} this configure manager.
     * @memberof IConfigureManager
     */
    useConfiguration(config?: string | T): this;
    /**
     * get config.
     *
     * @returns {Promise<T>}
     * @memberof IConfigureManager
     */
    getConfig(): Promise<T>;
}
